@@ -14,7 +14,7 @@ from tensorflow.keras.layers import Conv2D, BatchNormalization, Activation, MaxP
 
 trainpath = r"./train/"
 testpath = r"./test/"
-
+os.environ[“TF_CPP_MIN_LOG_LEVEL”]='3'
 np.set_printoptions(threshold=np.inf)
 
 from tensorflow.compat.v1 import ConfigProto
@@ -277,18 +277,22 @@ def process():
           workers=1)
     model.summary()
 
-def predictPicture(modelpath,imagepath):
+model = Baseline()
+
+def predictPicture(imagepath,modelpath = None):
     s = time.time()
     imagepath = r"{}".format(imagepath)
-    model = Baseline()
-    checkpoint_path = os.path.join(modelpath,"save.ckpt")
+    #model = Baseline()
+    
     
     result = []
-    if os.path.exists(checkpoint_path + '.index'):
-        print('-------------load the model-----------------')
-        model.load_weights(checkpoint_path)
-    else:
-        return "error:model is not exists in "+checkpoint_path
+    if modelpath:
+        checkpoint_path = os.path.join(modelpath,"save.ckpt")
+        if os.path.exists(checkpoint_path + '.index'):
+            print('-------------load the model-----------------')
+            model.load_weights(checkpoint_path)
+        else:
+            return "error:model is not exists in "+checkpoint_path
         
     x = readBmp([imagepath],500,500,"bmp")
     stream = np.array(x)
@@ -298,7 +302,7 @@ def predictPicture(modelpath,imagepath):
     imagename = os.path.basename(imagepath)
     maybe = result_index[0]
     percent = 100.0*result[0][maybe]
-    e = time.time
+    e = time.time()
     
     result = "name:{},maybe:{},percent:{}%,spend:{}s".format(imagename,maybe,round(percent,2),round(e-s,2))
     return result
